# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class StatesEnum(str, Enum):
    """
    * `skipped` - skipped * `completed` - completed * `failed` - failed * `canceled` - canceled
    """

    """
    allowed enum values
    """
    SKIPPED = 'skipped'
    COMPLETED = 'completed'
    FAILED = 'failed'
    CANCELED = 'canceled'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of StatesEnum from a JSON string"""
        return cls(json.loads(json_str))


