# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.generic_remote_response_policy_enum import GenericRemoteResponsePolicyEnum

class TestGenericRemoteResponsePolicyEnum(unittest.TestCase):
    """GenericRemoteResponsePolicyEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGenericRemoteResponsePolicyEnum(self):
        """Test GenericRemoteResponsePolicyEnum"""
        # inst = GenericRemoteResponsePolicyEnum()

if __name__ == '__main__':
    unittest.main()
