# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.paginated_task_response_list import PaginatedTaskResponseList

class TestPaginatedTaskResponseList(unittest.TestCase):
    """PaginatedTaskResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedTaskResponseList:
        """Test PaginatedTaskResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedTaskResponseList`
        """
        model = PaginatedTaskResponseList()
        if include_optional:
            return PaginatedTaskResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    crc-pulpcore-client.models.task_response.TaskResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        state = '', 
                        name = '', 
                        logging_cid = '', 
                        created_by = '', 
                        unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error = crc-pulpcore-client.models.error.error(), 
                        worker = '', 
                        parent_task = '', 
                        child_tasks = [
                            ''
                            ], 
                        task_group = '', 
                        progress_reports = [
                            crc-pulpcore-client.models.progress_report_response.ProgressReportResponse(
                                message = '', 
                                code = '', 
                                state = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        created_resources = [
                            ''
                            ], 
                        reserved_resources_record = [
                            ''
                            ], )
                    ]
            )
        else:
            return PaginatedTaskResponseList(
                count = 123,
                results = [
                    crc-pulpcore-client.models.task_response.TaskResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        state = '', 
                        name = '', 
                        logging_cid = '', 
                        created_by = '', 
                        unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error = crc-pulpcore-client.models.error.error(), 
                        worker = '', 
                        parent_task = '', 
                        child_tasks = [
                            ''
                            ], 
                        task_group = '', 
                        progress_reports = [
                            crc-pulpcore-client.models.progress_report_response.ProgressReportResponse(
                                message = '', 
                                code = '', 
                                state = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        created_resources = [
                            ''
                            ], 
                        reserved_resources_record = [
                            ''
                            ], )
                    ],
        )
        """

    def testPaginatedTaskResponseList(self):
        """Test PaginatedTaskResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
