# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.paginated_task_group_response_list import PaginatedTaskGroupResponseList

class TestPaginatedTaskGroupResponseList(unittest.TestCase):
    """PaginatedTaskGroupResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedTaskGroupResponseList:
        """Test PaginatedTaskGroupResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedTaskGroupResponseList`
        """
        model = PaginatedTaskGroupResponseList()
        if include_optional:
            return PaginatedTaskGroupResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    crc-pulpcore-client.models.task_group_response.TaskGroupResponse(
                        pulp_href = '', 
                        prn = '', 
                        description = '', 
                        all_tasks_dispatched = True, 
                        waiting = 56, 
                        skipped = 56, 
                        running = 56, 
                        completed = 56, 
                        canceled = 56, 
                        failed = 56, 
                        canceling = 56, 
                        group_progress_reports = [
                            crc-pulpcore-client.models.group_progress_report_response.GroupProgressReportResponse(
                                message = '', 
                                code = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        tasks = [
                            crc-pulpcore-client.models.minimal_task_response.MinimalTaskResponse(
                                pulp_href = '', 
                                prn = '', 
                                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                state = '', 
                                unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                worker = '', )
                            ], )
                    ]
            )
        else:
            return PaginatedTaskGroupResponseList(
                count = 123,
                results = [
                    crc-pulpcore-client.models.task_group_response.TaskGroupResponse(
                        pulp_href = '', 
                        prn = '', 
                        description = '', 
                        all_tasks_dispatched = True, 
                        waiting = 56, 
                        skipped = 56, 
                        running = 56, 
                        completed = 56, 
                        canceled = 56, 
                        failed = 56, 
                        canceling = 56, 
                        group_progress_reports = [
                            crc-pulpcore-client.models.group_progress_report_response.GroupProgressReportResponse(
                                message = '', 
                                code = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        tasks = [
                            crc-pulpcore-client.models.minimal_task_response.MinimalTaskResponse(
                                pulp_href = '', 
                                prn = '', 
                                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                state = '', 
                                unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                worker = '', )
                            ], )
                    ],
        )
        """

    def testPaginatedTaskGroupResponseList(self):
        """Test PaginatedTaskGroupResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
