# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MethodEnum(str, Enum):
    """
    * `write` - Export by writing * `hardlink` - Export by hardlinking * `symlink` - Export by symlinking
    """

    """
    allowed enum values
    """
    WRITE = 'write'
    HARDLINK = 'hardlink'
    SYMLINK = 'symlink'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MethodEnum from a JSON string"""
        return cls(json.loads(json_str))


