# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.upstream_pulp import UpstreamPulp

class TestUpstreamPulp(unittest.TestCase):
    """UpstreamPulp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpstreamPulp:
        """Test UpstreamPulp
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpstreamPulp`
        """
        model = UpstreamPulp()
        if include_optional:
            return UpstreamPulp(
                name = '0',
                base_url = '0',
                api_root = '0',
                domain = '0',
                ca_cert = '0',
                client_cert = '0',
                client_key = '0',
                tls_validation = True,
                username = '0',
                password = '0',
                q_select = '',
                policy = 'all'
            )
        else:
            return UpstreamPulp(
                name = '0',
                base_url = '0',
                api_root = '0',
        )
        """

    def testUpstreamPulp(self):
        """Test UpstreamPulp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
